@@ -1,6 +1,6 @@
 package Shipment::UPS;
 BEGIN {
-  $Shipment::UPS::VERSION = '0.01111730';
+  $Shipment::UPS::VERSION = '0.01112490';
 }
 use strict;
 use warnings;
@@ -260,8 +260,14 @@ sub _build_services {
 
   } catch {
       warn $_;
-      warn $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description;
-      $self->error( $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description->get_value );
+      try {
+        warn $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description;
+        $self->error( $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description->get_value );
+      } catch {
+        warn $_;
+        warn $response->get_faultstring;
+        $self->error( $response->get_faultstring->get_value );
+      };
   };
 
 
@@ -393,8 +399,14 @@ sub rate {
     }
   } catch {
       warn $_;
-      warn $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description;
-      $self->error( $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description->get_value );
+      try {
+        warn $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description;
+        $self->error( $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description->get_value );
+      } catch {
+        warn $_;
+        warn $response->get_faultstring;
+        $self->error( $response->get_faultstring->get_value );
+      };
   };
 
 }
@@ -627,8 +639,14 @@ sub ship {
 
   } catch {
       warn $_;
-      warn $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description;
-      $self->error( $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description->get_value );
+      try {
+        warn $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description;
+        $self->error( $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description->get_value );
+      } catch {
+        warn $_;
+        warn $response->get_faultstring;
+        $self->error( $response->get_faultstring->get_value );
+      };
   };
 
 }
@@ -842,8 +860,14 @@ sub return {
 
   } catch {
       warn $_;
-      warn $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description;
-      $self->error( $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description->get_value );
+      try {
+        warn $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description;
+        $self->error( $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description->get_value );
+      } catch {
+        warn $_;
+        warn $response->get_faultstring;
+        $self->error( $response->get_faultstring->get_value );
+      };
   };
 
 }
@@ -910,8 +934,14 @@ sub cancel {
 
   } catch {
       warn $_;
-      warn $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description;
-      $self->error( $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description->get_value );
+      try {
+        warn $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description;
+        $self->error( $response->get_detail()->get_Errors()->get_ErrorDetail()->get_PrimaryErrorCode()->get_Description->get_value );
+      } catch {
+        warn $_;
+        warn $response->get_faultstring;
+        $self->error( $response->get_faultstring->get_value );
+      };
   };
 
   return $success;
@@ -933,7 +963,7 @@ Shipment::UPS
 
 =head1 VERSION
 
-version 0.01111730
+version 0.01112490
 
 =head1 SYNOPSIS
 
